@@ -17,9 +17,11 @@ XAO::DO::Web::Content.
 
 =head1 AUTHORS
 
-Copyright (c) 2002 XAO Inc.
+Copyright (c) 2005 Andrew Maltsev
 
-Andrew Maltsev <am@xao.com>.
+Copyright (c) 2001-2004 Andrew Maltsev, XAO Inc.
+
+<am@ejelta.com> -- http://ejelta.com/xao/
 
 =head1 SEE ALSO
 
