@@ -1,4 +1,6 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
+use warnings;
+use strict;
 
 eval "use XAO::TestUtils";
 if($@) { die "Can't find XAO::Base - call as ``perl -Mblib $0'' ($@)\n" }
